@@ -9,6 +9,8 @@ __author__ = 'jstorm'
 
 
 def test_import_of_all_modules():
+    from transmedia import conversion
     from transmedia import encoders
-    from transmedia import bytes2png
-    from transmedia import png2bytes
+    from transmedia import io
+    from transmedia import util
+    from transmedia import transform_png
